TiffPlanarConfiguration enum

PlanarConfiguration (tag 284): how samples of a pixel are arranged.

Inheritance
Available extensions

Values

chunky → const TiffPlanarConfiguration

Chunky/interleaved: R,G,B,R,G,B,... (the common case).

const TiffPlanarConfiguration(1)
planar → const TiffPlanarConfiguration

Planar: all R values, then all G values, then all B values.

const TiffPlanarConfiguration(2)

Properties

code int
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCode(int code) TiffPlanarConfiguration

Constants

values → const List<TiffPlanarConfiguration>
A constant List of the values in this enum, in order of their declaration.