pyramidLevelsPath property

String? pyramidLevelsPath
final

Optional sidecar TIFF whose pages are extra, smaller rungs of the page — e.g. the output of TiffDisplayOptimizer.optimizeLargeSourcePyramidLevels for a page with no pyramid of its own. Pages whose aspect ratio doesn't match are ignored.

Implementation

final String? pyramidLevelsPath;