showLoadingIndicator property
Whether a small progress indicator shows in the top-left corner while tiles are loading.
Implementation
final bool showLoadingIndicator;
Whether a small progress indicator shows in the top-left corner while tiles are loading.
final bool showLoadingIndicator;