TiffPhotometric enum
PhotometricInterpretation (tag 262): how sample values map to color.
Values
- whiteIsZero → const TiffPhotometric
-
const TiffPhotometric(0) - blackIsZero → const TiffPhotometric
-
const TiffPhotometric(1) - rgb → const TiffPhotometric
-
const TiffPhotometric(2) - palette → const TiffPhotometric
-
const TiffPhotometric(3) - transparencyMask → const TiffPhotometric
-
const TiffPhotometric(4) - cmyk → const TiffPhotometric
-
const TiffPhotometric(5) - ycbcr → const TiffPhotometric
-
const TiffPhotometric(6) - cielab → const TiffPhotometric
-
const TiffPhotometric(8)
Properties
- code → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCode(
int code) → TiffPhotometric?
Constants
-
values
→ const List<
TiffPhotometric> - A constant List of the values in this enum, in order of their declaration.