controller property
The transform of the viewer this minimap overlays — read to draw the current viewport rectangle, and written (via onNavigate, or directly if that's left unset) when the user taps or drags on the minimap.
Implementation
final TransformationController controller;